<?php

/**
 * Helper functions. Get a group.
 * 
 * @param string $id
 * @param array $group_info
 * @return object 
 */
function social_groups_get_instance($id, $group_info) {
  static $instances;
 
  if (!isset($instances[$id])) {
    ctools_include('plugins');
    $plugin = ctools_get_plugins('social_groups', 'plugins', $id);
    $class = ctools_plugin_get_class($plugin, 'handler');
    
    $class_info = new ReflectionClass($class);
    if (!$class_info->isAbstract()) {
      $instances[$id] = new $class($group_info);
      // Check that plugin class has ingerited proper 'SocialGroupPlugin' class.
      if (!is_subclass_of($instances[$id], 'SocialGroupPlugin')) {
        $instances[$id] = NULL;
      }
    }  
  }
  
  return $instances[$id];
}

/**
 * Validate callback.
 */
function social_groups_group_form_validate($form, $form_state) {
  // Load all plugins type "plugins".
  ctools_include('plugins');
  $plugins = ctools_get_plugins('social_groups', 'plugins');

  foreach ($plugins as $id => $plugin) {
    if (isset($form_state['values'][$id])) {
      if ($group = social_groups_get_instance($id, $plugin['group'])) {
        $result = $group->setGroup($form_state['values'][$id]);
        if ($result) {
          form_set_error($id . '][' . $result['field'], $result['message']);
        }
      }
    }
  }
  
}

/**
 * Helper function. Block list.
 * 
 * @return array
 */
function _social_groups_block_list() {
  $blocks = array();

  $blocks['social_groups'] = array(
    'info' => t('Social groups'),
    'cache' => DRUPAL_NO_CACHE,
  );

  return $blocks;
}

/**
 * Helper function. Block configure.
 * 
 * @return array
 */
function _social_groups_block_configure($delta = '') {
  $form = array();

  if ($delta == 'social_groups') {
    // Load all plugins type "plugins".
    ctools_include('plugins');
    $plugins = ctools_get_plugins('social_groups', 'plugins');
    
    foreach ($plugins as $id => $plugin) {
      if ($group = social_groups_get_instance($id, $plugin['group'])) {
        $form[$id] = array(
          '#type' => 'fieldset',
          '#tree' => TRUE,
        );
        $items = $group->getForm();
        
        $form[$id] += $items;
      }
    }
  }
  
  return $form;
 }
 
/**
 * Helper function. Block view.
 * 
 * @return array
 */
function _social_groups_block_view($delta = '') {
  $block = array();

  switch ($delta) {
    case 'social_groups':
      // Load all plugins type "plugins".
      ctools_include('plugins');
      $plugins = ctools_get_plugins('social_groups', 'plugins');
      
      $output = array();
      foreach ($plugins as $id => $plugin) {
        if ($group = social_groups_get_instance($id, $plugin['group'])) {
          $output[$group->getName()] = $group->getData();
        }
      }
      
      $block['subject'] = t('Social groups');
      $block['content'] = theme('social_groups', array('groups' => $output));
      break;
  }
  
  return $block;
}